@@ -2,7 +2,7 @@ import asyncio
 
 import pytest
 
-from aiorwlock import RWLock, _current_task
+from aiorwlock import RWLock
 
 
 class Bunch(object):
@@ -24,7 +24,7 @@ class Bunch(object):
         self._futures = []
 
         async def task():
-            tid = _current_task()
+            tid = asyncio.current_task()
             self.started.append(tid)
             try:
                 await f()
@@ -48,22 +48,6 @@ async def _wait():
     await asyncio.sleep(0.01)
 
 
-def test_ctor_deprecated_implicit_not_running(loop):
-    with pytest.warns(DeprecationWarning):
-        RWLock()
-
-
-def test_ctor_deprecated_explicit_non_running(loop):
-    with pytest.warns(DeprecationWarning):
-        RWLock(loop=loop)
-
-
-@pytest.mark.asyncio
-async def test_ctor_loop_deprecated_arg(loop):
-    with pytest.warns(DeprecationWarning):
-        RWLock(loop=loop)
-
-
 @pytest.mark.asyncio
 async def test_ctor_loop_reader(loop):
     rwlock = RWLock().reader_lock
@@ -500,14 +484,6 @@ async def test_write_read_lock_multiple_tasks(loop, fast_track):
     assert not wl.locked
 
 
-def test_current_task(loop):
-    with pytest.raises(RuntimeError):
-        _current_task(loop)
-
-    with pytest.raises(RuntimeError):
-        _current_task()
-
-
 @pytest.mark.asyncio
 async def test_read_context_manager(loop, fast_track):
     rwlock = RWLock(fast=fast_track)
